/* 
Stata code for:

Ehrmann, Michael and David-Jan Jansen. 2016. "The pitch rather than the pit: Investor inattention 
during FIFA World Cup matches". Forthcoming at the Journal of Money, Credit and Banking.

Please note that the underlying stock data are proprietary and are not included in this zip-files.

This do-file calls "ReportC2010.do" and "ReportC2014.do", the results of which are reported in the online appendix at:
https://sites.google.com/site/djansenresearch/replication/investorinattentionjmcb

Contact: djansenresearch@gmail.com
3 August 2016. 
*/

	/// PRELIMINARIES
clear all
capture adopath + "..."   	// add ado-directory
set more off
global workdir "..."		// specify working directory
cd "$workdir/AnalysisJMCB"

capture log close
local 	stamp "$S_DATE"
log 	using "$workdir/AnalysisJMCB/LogFileJMCB_`stamp'.log", replace

//////////////////////////////////////////////////////////////////////////////
//				2010														//
//////////////////////////////////////////////////////////////////////////////

	/// READ IN 2010 DATA, DEFINE GLOBALS
use "$workdir/Data/Dataset_July2012.dta", clear			// proprietary data, cannot be shared

label var gametime_all_benchmark "Matches by other teams"
label var game_time				 "National team matches"

// construct gamecounter for clustering, based on 21 matches in Table 1. Note some matches overlap, so we have 20 clusters 
g gamecounter = 0

replace gamecounter	= 1  	if month == 6 & day == 11 & time >= 16.0 & time <= 17.805
replace gamecounter	= 2  	if month == 6 & day == 14 & time >= 13.5 & time <= 15.305
replace gamecounter	= 3  	if month == 6 & day == 15 & time >= 16.0 & time <= 17.805
replace gamecounter	= 4  	if month == 6 & day == 15 & time >= 20.5 & time <= 22.305
replace gamecounter	= 5  	if month == 6 & day == 16 & time >= 16.0 & time <= 17.805
replace gamecounter	= 6  	if month == 6 & day == 17 & time >= 20.5 & time <= 22.305
replace gamecounter	= 7  	if month == 6 & day == 18 & time >= 13.5 & time <= 15.3167
replace gamecounter	= 8  	if month == 6 & day == 18 & time >= 16.0 & time <= 17.8334
replace gamecounter	= 9		if month == 6 & day == 21 & time >= 16.0 & time <= 17.8167
replace gamecounter	= 10  	if month == 6 & day == 21 & time >= 13.5 & time <= 15.305
replace gamecounter	= 11  	if month == 6 & day == 22 & time >= 16.0 & time <= 17.805
replace gamecounter	= 12  	if month == 6 & day == 22 & time >= 20.5 & time <= 22.305
replace gamecounter	= 13  	if month == 6 & day == 23 & time >= 16.0 & time <= 17.805
replace gamecounter	= 14  	if month == 6 & day == 24 & time >= 16.0 & time <= 17.805
replace gamecounter	= 15  	if month == 6 & day == 25 & time >= 16.0 & time <= 17.834
replace gamecounter	= 16  	if month == 6 & day == 25 & time >= 20.5 & time <= 22.305
replace gamecounter	= 17  	if month == 6 & day == 28 & time >= 16.0 & time <= 17.805
replace gamecounter	= 18  	if month == 6 & day == 28 & time >= 20.5 & time <= 22.305
replace gamecounter	= 19  	if month == 7 & day == 2  & time >= 16.0 & time <= 17.805

// gamecounter for anthem/duration1&2 variables in regressions 
g gamecounter2 = 0

replace gamecounter2	= 1  	if month == 6 & day == 11 & time >= 15.75 & time <= 18.805
replace gamecounter2	= 2  	if month == 6 & day == 14 & time >= 13.25 & time <= 16.305
replace gamecounter2	= 3  	if month == 6 & day == 15 & time >= 15.75 & time <= 18.805
replace gamecounter2	= 4  	if month == 6 & day == 15 & time >= 20.25 & time <= 23.305
replace gamecounter2	= 5  	if month == 6 & day == 16 & time >= 15.75 & time <= 18.805
replace gamecounter2	= 6  	if month == 6 & day == 17 & time >= 20.25 & time <= 23.305
replace gamecounter2	= 7  	if month == 6 & day == 18 & time >= 13.25 & time <= 16.3167
replace gamecounter2	= 8  	if month == 6 & day == 18 & time >= 15.75 & time <= 18.8334
replace gamecounter2	= 9		if month == 6 & day == 21 & time >= 15.75 & time <= 18.8167
replace gamecounter2	= 10  	if month == 6 & day == 21 & time >= 13.25 & time <= 16.305
replace gamecounter2	= 11  	if month == 6 & day == 22 & time >= 15.75 & time <= 18.805
replace gamecounter2	= 12  	if month == 6 & day == 22 & time >= 20.25 & time <= 23.305
replace gamecounter2	= 13  	if month == 6 & day == 23 & time >= 15.75 & time <= 18.805
replace gamecounter2	= 14  	if month == 6 & day == 24 & time >= 15.75 & time <= 18.805
replace gamecounter2	= 15  	if month == 6 & day == 25 & time >= 15.75 & time <= 18.834
replace gamecounter2	= 16  	if month == 6 & day == 25 & time >= 20.25 & time <= 23.305
replace gamecounter2	= 17  	if month == 6 & day == 28 & time >= 15.75 & time <= 18.805
replace gamecounter2	= 18  	if month == 6 & day == 28 & time >= 20.25 & time <= 23.305
replace gamecounter2	= 19  	if month == 7 & day == 2  & time >= 15.75 & time <= 18.805

// country dummies for the FE estimates
tab country, g(dumc_)

compress

// tod dummies
//g tod = hour*60+minute
tab tod, g(dumtod_)

// month dummies
tab month, g(dummonth_)

// ATA for charts
gen tick_t_diff_chart		= tick_t_diff
replace tick_t_diff_chart	= . 			if tick_t_diff_chart>200
gen vol_t_diff_chart		= vol_t_diff
replace vol_t_diff_chart	= . 			if vol_t_diff_chart>200

// duration dummy for own matches (based on time and Table 1) 
g 		durationa1 = 0
g 		durationa2 = 0

replace durationa1	= 1  	if month == 6 & day == 11 & time > 17.805 & time <= 18.305 & (cty == "SouthAfrica" | cty == "Mexico") 
replace durationa1	= 1  	if month == 6 & day == 14 & time > 15.305 & time <= 15.805 & (cty == "Netherlands" | cty == "Denmark") 
replace durationa1	= 1  	if month == 6 & day == 15 & time > 17.805 & time <= 18.305 & cty == "Portugal"
replace durationa1	= 1  	if month == 6 & day == 15 & time > 22.305 & time <= 22.805 & cty == "Brazil" 
replace durationa1	= 1  	if month == 6 & day == 16 & time > 17.805 & time <= 18.305 & (cty == "Spain" | cty == "Switzerland")
replace durationa1	= 1  	if month == 6 & day == 17 & time > 22.305 & time <= 22.805 & cty == "Mexico"
replace durationa1	= 1  	if month == 6 & day == 18 & time > 15.3167 & time <= 15.8167 & cty == "Germany"
replace durationa1	= 1  	if month == 6 & day == 18 & time > 17.8334 & time <= 18.3334 & cty == "UnitedStates"
replace durationa1	= 1		if month == 6 & day == 21 & time > 17.8167 & time <= 18.3167 & (cty == "Chile" | cty == "Switzerland")
replace durationa1	= 1  	if month == 6 & day == 21 & time > 15.305 & time <= 15.805 & cty == "Portugal"
replace durationa1	= 1  	if month == 6 & day == 22 & time > 17.805 & time <= 18.305 & (cty == "Mexico" | cty == "France" | cty == "SouthAfrica")
replace durationa1	= 1  	if month == 6 & day == 22 & time > 22.305 & time <= 22.805 & (cty == "Argentina")
replace durationa1	= 1  	if month == 6 & day == 23 & time > 17.805 & time <= 18.305 & (cty == "UnitedStates" | cty == "England")
replace durationa1	= 1  	if month == 6 & day == 24 & time > 17.805 & time <= 18.305 & cty == "Italy"
replace durationa1	= 1  	if month == 6 & day == 25 & time > 17.8340 & time <= 18.3340 & (cty == "Portugal" | cty == "Brazil")
replace durationa1	= 1  	if month == 6 & day == 25 & time > 22.305 & time <= 22.805 & (cty == "Chile")
replace durationa1	= 1  	if month == 6 & day == 28 & time > 17.805 & time <= 18.305 & (cty == "Netherlands")
replace durationa1	= 1  	if month == 6 & day == 28 & time > 22.305 & time <= 22.805 & (cty == "Brazil" | cty == "Chile")
replace durationa1	= 1  	if month == 7 & day == 2  & time > 17.805 & time <= 18.305 & (cty == "Netherlands" | cty == "Brazil")

replace durationa2	= 1  	if month == 6 & day == 11 & time > 18.305 & time <= 18.805 & (cty == "SouthAfrica" | cty == "Mexico")
replace durationa2	= 1  	if month == 6 & day == 14 & time > 15.805 & time <= 16.305 & (cty == "Netherlands" | cty == "Denmark") 
replace durationa2	= 1  	if month == 6 & day == 15 & time > 18.305 & time <= 18.805 & cty == "Portugal"
replace durationa2	= 1  	if month == 6 & day == 15 & time > 22.805 & time <= 23.305 & cty == "Brazil" 
replace durationa2	= 1  	if month == 6 & day == 16 & time > 18.305 & time <= 18.805 & (cty == "Spain" | cty == "Switzerland")
replace durationa2	= 1  	if month == 6 & day == 17 & time > 22.805 & time <= 23.305 & cty == "Mexico"
replace durationa2	= 1  	if month == 6 & day == 18 & time > 15.8167 & time <= 16.3167 & cty == "Germany"
replace durationa2	= 1  	if month == 6 & day == 18 & time > 18.3334 & time <= 18.8334 & cty == "UnitedStates"
replace durationa2	= 1		if month == 6 & day == 21 & time > 18.3167 & time <= 18.8167 & (cty == "Chile" | cty == "Switzerland")
replace durationa2	= 1  	if month == 6 & day == 21 & time > 15.805 & time <= 16.305 & cty == "Portugal"
replace durationa2	= 1  	if month == 6 & day == 22 & time > 18.305 & time <= 18.805 & (cty == "Mexico" | cty == "France" | cty == "SouthAfrica")
replace durationa2	= 1  	if month == 6 & day == 22 & time > 22.805 & time <= 23.305 & (cty == "Argentina")
replace durationa2	= 1  	if month == 6 & day == 23 & time > 18.305 & time <= 18.805 & (cty == "UnitedStates" | cty == "England")
replace durationa2	= 1  	if month == 6 & day == 24 & time > 18.305 & time <= 18.805 & cty == "Italy"
replace durationa2	= 1  	if month == 6 & day == 25 & time > 18.3340 & time <= 18.8340 & (cty == "Portugal" | cty == "Brazil")
replace durationa2	= 1  	if month == 6 & day == 25 & time > 22.805 & time <= 23.305 & (cty == "Chile")
replace durationa2	= 1  	if month == 6 & day == 28 & time > 18.305 & time <= 18.805 & (cty == "Netherlands")
replace durationa2	= 1  	if month == 6 & day == 28 & time > 22.805 & time <= 23.305 & (cty == "Brazil" | cty == "Chile")
replace durationa2	= 1  	if month == 7 & day == 2  & time > 18.305 & time <= 18.805 & (cty == "Netherlands" | cty == "Brazil")

label var durationa1 "1st half-hour after game"
label var durationa2 "2nd half-hour after game"

// interact durations
foreach varia in a1 a2 {
g interactduration`varia' = duration`varia'*stockreturn_MSCI
}

// interact aftermaths
foreach varia in 1 2 3 {
g interactaftermath`varia' = aftermath`varia'*stockreturn_MSCI
}

save 	"$workdir/AnalysisJMCB/Dataset2010JMCB.dta", replace

//global
global RHS10 gametime_all_benchmark game_time
global RHSmatchevents1  r5goal r5card anthem1 halftime aftermath1 aftermath2 aftermath3
global RHSmatchevents2  r5goal r5card anthem1 halftime durationa1 durationa2

////////////////////////////////////////////////////////////////////////////////

	/// 2010: ATA FIGURES TRADES AND TRADED VOLUMES (Figure 1, left column)

foreach type in tick {
twoway__histogram_gen `type'_t_diff_chart if gametime_compare==0, percent width(10) gen(h1`type' x1`type')
twoway__histogram_gen `type'_t_diff_chart if gametime_compare==1, percent width(10) gen(h2`type' x2`type')
#delimit ;
	twoway 
	(bar h1`type' x1`type', barw(10) bc(gs9)) 
	(bar h2`type' x2`type', barw(5) bc(gs0) ) 
	, 
	xlabel(-100[100]200) 
	ylabel(0(4)12, glc(gs12))
	xti("")  
	yti("Number of trades")
	title("2010")
	legend(off)  
	graphregion(fcolor(gs16))
	;
#delimit cr	
graph save "$workdir/AnalysisJMCB/`type'_t_diff_overall10", replace
drop x1`type'-h2`type'
}

foreach type in vol{
twoway__histogram_gen `type'_t_diff_chart if gametime_compare==0, percent width(10) gen(h1`type' x1`type')
twoway__histogram_gen `type'_t_diff_chart if gametime_compare==1, percent width(10) gen(h2`type' x2`type')
#delimit ;
	twoway 
	(bar h1`type' x1`type', barw(10) bc(gs9)) 
	(bar h2`type' x2`type', barw(5) bc(gs0) ) 
	, 
	xlabel(-100[100]200) 
	ylabel(0(4)12, glc(gs12))
	xti("")  
	yti("Traded volumes")
	title("2010")
	legend(off)  
	graphregion(fcolor(gs16))
	;
#delimit cr	
graph save "$workdir/AnalysisJMCB/`type'_t_diff_overall10", replace
drop x1`type'-h2`type'
}

////////////////////////////////////////////////////////////////////////////////////////////////

	/// 1a. ATA FOR TICKS FOR 2010
eststo atat10ols1:		reg 		tick_t_diff $RHS10
eststo atat10ols2:		reg 		tick_t_diff $RHS10			, vce(cl cty)
eststo atat10ols3:		reg 		tick_t_diff $RHS10			, vce(cl gamecounter)
eststo atat10pcse1:		xtpcse 		tick_t_diff $RHS10			, 
eststo atat10qreg:		qreg		tick_t_diff $RHS10			,
eststo atat10qregr:		qreg		tick_t_diff $RHS10			, vce(r)
eststo atat10bsqreg:	bsqreg		tick_t_diff $RHS10			, 
eststo atat10qreg4:		qreg2		tick_t_diff $RHS10			, cluster(cty) notest
eststo atat10qreg5:		qreg2		tick_t_diff $RHS10			, cluster(gamecounter) notest

#delimit ;
esttab atat10ols1 atat10ols2 atat10ols3 atat10pcse1 atat10qreg atat10qregr atat10bsqreg atat10qreg4 atat10qreg5
	using "$workdir/AnalysisJMCB/TableR2.csv", 
	b(2) se(2) ar(2) 
	star(* 0.05 ** 0.01)
	keep(gametime_all_benchmark game_time _cons)
	nonotes nogaps 
	label fragment
	br
	mtitles("OLS" "OLS+cl cty" "OLS+cl game" "PCSE" "Median" "Median+robust" "Median+boots" "Median+cl cty" "Median+cl game")
	replace 
	;
#delimit cr

	/// 1b. ATA FOR VOLUMES FOR 2010
eststo atav10ols1:		reg 		vol_t_diff $RHS10
eststo atav10ols2:		reg 		vol_t_diff $RHS10			, vce(cl cty)
eststo atav10ols3:		reg 		vol_t_diff $RHS10			, vce(cl gamecounter)
eststo atav10pcse1:		xtpcse 		vol_t_diff $RHS10			, 
eststo atav10qreg:		qreg		vol_t_diff $RHS10			,
eststo atav10qregr:		qreg		vol_t_diff $RHS10			, vce(r)
eststo atav10bsqreg:	bsqreg		vol_t_diff $RHS10			, 
eststo atav10qreg4:		qreg2		vol_t_diff $RHS10			, cluster(cty) notest
eststo atav10qreg5:		qreg2		vol_t_diff $RHS10			, cluster(gamecounter) notest

#delimit ;
esttab atav10ols1 atav10ols2 atav10ols3 atav10pcse1 atav10qreg atav10qregr atav10bsqreg atav10qreg4 atav10qreg5 
	using "$workdir/AnalysisJMCB/TableR3.csv", 
	b(2) se(2) ar(2) 
	star(* 0.05 ** 0.01)
	keep(gametime_all_benchmark game_time _cons)
	nonotes nogaps
	label fragment
	br
	mtitles("OLS" "OLS+cl cty" "OLS+cl game" "PCSE" "Median" "Median+robust" "Median+boots" "Median+cl cty" "Median+cl game")
	replace 
	;
#delimit cr


	/// 1e. Match events during national team matches 
eststo atat10olsclgamematchevents:	reg		tick_t_diff	game_time $RHSmatchevents2 if tradingtime==1, vce(cl gamecounter2)
eststo atav10olsclgamematchevents:	reg		vol_t_diff 	game_time $RHSmatchevents2 if tradingtime==1, vce(cl gamecounter2)


	/// 2. DECOUPLING RESULTS 2010 (Table 5, column 1)
#delimit ;
	eststo decoupl10: 
	xtpcse stockreturn 
	stockreturn_MSCI interact game_time 
	durationa1 durationa2
	interactdurationa1 interactdurationa2 
	if 
	tradingtime == 1
	,
	pairw
	;
#delimit cr


	/// 3. RESPONSE TO REFEREE REPORT C (in Appendix)
do 		"$workdir/AnalysisJMCB/ReportC2010.do"

clear

//////////////////////////////////////////////////////////////////////////////
//				2014														//
//////////////////////////////////////////////////////////////////////////////


	/// CONSTRUCT 2014 DATA SET 
do 		"$workdir/AnalysisJMCB/Construct2014DataJMCB.do"	// calls proprietary data, cannot be shared

cd "$workdir/AnalysisJMCB"  // because cd in code before

// create vars for eststo output comparable 2010 & 2014
g gametime_all 				= gameothers + owngame
g gametime_all_benchmark 	= gameothers
g game_time					= owngame
label var gametime_all_benchmark "Matches by other teams"
label var game_time				 "National team matches"

// construct gamecounter for clustering, based on 7 matches in Table 1
g gamecounter 		= 0
replace gamecounter	= 1  	if month == 6 & day == 13 & time >= 12.0 & time <= 13.91667
replace gamecounter	= 2  	if month == 6 & day == 17 & time >= 15.0 & time <= 16.805
replace gamecounter	= 3  	if month == 6 & day == 18 & time >= 15.0 & time <= 16.805
replace gamecounter	= 4  	if month == 6 & day == 23 & time >= 12.0 & time <= 13.851
replace gamecounter	= 5  	if month == 6 & day == 25 & time >= 12.0 & time <= 13.8834
replace gamecounter	= 6  	if month == 6 & day == 26 & time >= 12.0 & time <= 13.8667
replace gamecounter	= 7  	if month == 7 & day == 1  & time >= 12.0 & time <= 14.5667

// gamecounter for anthem / duration variables in regressions
g gamecounter2 			= 0
replace gamecounter2	= 1  	if month == 6 & day == 13 & time >= 11.75 & time <= 14.91667
replace gamecounter2	= 2  	if month == 6 & day == 17 & time >= 14.75 & time <= 17.805
replace gamecounter2	= 3  	if month == 6 & day == 18 & time >= 14.75 & time <= 17.805
replace gamecounter2	= 4  	if month == 6 & day == 23 & time >= 11.75 & time <= 14.851
replace gamecounter2	= 5  	if month == 6 & day == 25 & time >= 11.75 & time <= 14.8834
replace gamecounter2	= 6  	if month == 6 & day == 26 & time >= 11.75 & time <= 14.8667
replace gamecounter2	= 7  	if month == 7 & day == 1  & time >= 11.75 & time <= 15.5667

// country dummies for the FE estimates
tab country, g(dumc_)

// returns etc for decoupling analysis
gen stockreturn=(stockindex-L.stockindex)/L.stockindex*100
g stockreturn_MSCI=100*(msci_world-L.msci_world)/L.msci_world
gen interact=stockreturn_MSCI*game_time
//tsset country t
foreach lag in 1 2 3 {
gen stockreturn_lag`lag'=L`lag'.stockreturn
gen stockreturn_MSCI_lag`lag'=L`lag'.stockreturn_MSCI
gen interact_lag`lag'=stockreturn_MSCI_lag`lag'*game_time
}

// excess returns etc for decoupling
gen tbill_3month=us3mtbill/518400
gen excessreturn_MSCI=stockreturn_MSCI-tbill_3month
gen excessreturn=stockreturn-tbill_3month
gen excessinteract=excessreturn_MSCI*owngame
gen excessinteract_others=excessreturn_MSCI*gameothers
foreach lag in 1 2 3 {
gen excessreturn_lag`lag'=L`lag'.excessreturn
}

tab dow, g(ddummy)
g tod_5 = hour*60+minute/5
g help = int(tod_5)
tab help, g(tod5dummy)
drop help tod_5

// tod dummies (for sensit checks, no impact)
g tod = hour*60+minute
tab tod, g(dumtod_)

// month dummies
tab month, g(dummonth_)

// ATA for charts
gen tick_t_diff_chart=tick_t_diff
replace tick_t_diff_chart=. if tick_t_diff_chart>200
gen vol_t_diff_chart=vol_t_diff
replace vol_t_diff_chart=. if vol_t_diff_chart>200

// duration dummy for own matches (based on time and Table 1)
g 		durationa1 = 0
g 		durationa2 = 0

replace durationa1	= 1  	if month == 6 & day == 13 & time > 13.91667 & time <= 14.41667 	& (cty == "MX" | cty == "MMX")
replace durationa1	= 1  	if month == 6 & day == 17 & time > 16.805 	& time <= 17.305 	& (cty == "MX" | cty == "MMX")
replace durationa1	= 1  	if month == 6 & day == 18 & time > 16.805 	& time <= 17.305 	& (cty == "CL" | cty == "MCL")
replace durationa1	= 1  	if month == 6 & day == 23 & time > 13.8510 	& time <= 14.3510 	& (cty == "CL" | cty == "MCL")
replace durationa1	= 1  	if month == 6 & day == 25 & time > 13.8834 	& time <= 14.3834 	& (cty == "AR" | cty == "MAR")
replace durationa1	= 1  	if month == 6 & day == 26 & time > 13.8667 	& time <= 14.3667 	& (cty == "US" | cty == "MUS")
replace durationa1	= 1  	if month == 7 & day == 1  & time > 14.5667 	& time <= 15.0667 	& (cty == "AR" | cty == "MAR")

replace durationa2	= 1  	if month == 6 & day == 13 & time > 14.41667 & time <= 14.91667 	& (cty == "MX" | cty == "MMX")
replace durationa2	= 1  	if month == 6 & day == 17 & time > 17.305 	& time <= 17.805 	& (cty == "MX" | cty == "MMX")
replace durationa2	= 1  	if month == 6 & day == 18 & time > 17.305 	& time <= 17.805 	& (cty == "CL" | cty == "MCL")
replace durationa2	= 1  	if month == 6 & day == 23 & time > 14.3510 	& time <= 14.8510 	& (cty == "CL" | cty == "MCL")
replace durationa2	= 1  	if month == 6 & day == 25 & time > 14.3834 	& time <= 14.8834 	& (cty == "AR" | cty == "MAR")
replace durationa2	= 1  	if month == 6 & day == 26 & time > 14.3667 	& time <= 14.8667 	& (cty == "US" | cty == "MUS")
replace durationa2	= 1  	if month == 7 & day == 1  & time > 15.0667 	& time <= 15.5667 	& (cty == "AR" | cty == "MAR")

label var durationa1 "1st half-hour after game"
label var durationa2 "2nd half-hour after game"

// interact durations (returns & excess returns)
foreach varia in a1 a2 {
g interactduration`varia' 		= duration`varia'*stockreturn_MSCI
g excessinteractduration`varia' = duration`varia'*excessreturn_MSCI
}


// variables for match events
tsset stockmarket t 

gen anthem1=0
replace game_ticker=. if game_ticker==0
replace anthem1=1 if F.game_ticker~=. | F2.game_ticker~=. | F3.game_ticker~=. | F4.game_ticker~=. | F5.game_ticker~=. | F6.game_ticker~=. | F7.game_ticker~=. | F8.game_ticker~=. | F9.game_ticker~=. | F10.game_ticker~=. | F11.game_ticker~=. | F12.game_ticker~=. | F13.game_ticker~=. | F14.game_ticker~=. | F15.game_ticker~=.
replace anthem1=0 if owngame==1

gen aftermath1=0
replace aftermath1=1 if L.game_ticker~=. | L2.game_ticker~=. | L3.game_ticker~=. | L4.game_ticker~=. | L5.game_ticker~=. | L6.game_ticker~=. | L7.game_ticker~=. | L8.game_ticker~=. | L9.game_ticker~=. | L10.game_ticker~=. | L11.game_ticker~=. | L12.game_ticker~=. | L13.game_ticker~=. | L14.game_ticker~=. | L15.game_ticker~=.
replace aftermath1=0 if owngame==1
gen aftermath2=0
replace aftermath2=1 if L16.game_ticker~=. | L17.game_ticker~=. | L18.game_ticker~=. | L19.game_ticker~=. | L20.game_ticker~=. | L21.game_ticker~=. | L22.game_ticker~=. | L23.game_ticker~=. | L24.game_ticker~=. | L25.game_ticker~=. | L26.game_ticker~=. | L27.game_ticker~=. | L28.game_ticker~=. | L29.game_ticker~=. | L30.game_ticker~=.
replace aftermath2=0 if owngame==1 | aftermath1==1
gen aftermath3=0
replace aftermath3=1 if L31.game_ticker~=. | L32.game_ticker~=. | L33.game_ticker~=. | L34.game_ticker~=. | L35.game_ticker~=. | L36.game_ticker~=. | L37.game_ticker~=. | L38.game_ticker~=. | L39.game_ticker~=. | L40.game_ticker~=. | L41.game_ticker~=. | L42.game_ticker~=. | L43.game_ticker~=. | L44.game_ticker~=. | L45.game_ticker~=.
replace aftermath3=0 if owngame==1 | aftermath1==1 | aftermath2==1
gen game_time_ext=owngame
replace game_time_ext=1 if anthem1==1
replace game_time_ext=1 if aftermath1==1 | aftermath2==1 | aftermath3==1
replace game_ticker=0 if game_ticker==.

foreach type in corner_other freekick_other shotgoal_other shot_other goaldisallowed_other {
ren `type' `type's
}

foreach type in goal corner freekick shotgoal shot goaldisallowed {
gen `type' = `type'_own + `type'_others
}
gen card=yellowcard+redcard
foreach type in goal corner freekick shotgoal shot goaldisallowed card penalty {
gen r5`type'=`type'
replace r5`type'=1 if F.`type'==1 | F2.`type'==1 | L.`type'==1 | L2.`type'==1
}


// interact aftermatchs (returns & excess returns)
foreach varia in 1 2 3 {
g interactaftermath`varia' 			= aftermath`varia'*stockreturn_MSCI
g excessinteractaftermath`varia' 	= aftermath`varia'*excessreturn_MSCI
}

save 	"$workdir/AnalysisJMCB/Dataset2014JMCB.dta", replace

// global
global RHS14 gametime_all_benchmark game_time
global RHSmatchevents1  r5goal r5card anthem1 halftime aftermath1 aftermath2 aftermath3
global RHSmatchevents2  r5goal r5card anthem1 halftime durationa1 durationa2

///////////////////////////////////////////////////////////////////////////////

	/// 2014: ATA FIGURES TRADES AND TRADED VOLUMES (Figure 1, right column)

foreach type in tick {
twoway__histogram_gen `type'_t_diff_chart if gameslot==1 & wc==0 	& trade==1 & cty~="BR" & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", percent width(10) gen(h1`type' x1`type')
twoway__histogram_gen `type'_t_diff_chart if owngame==1 			& trade==1 & cty~="BR" & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", percent width(10) gen(h2`type' x2`type')
#delimit ;
	twoway 
	(bar h1`type' x1`type', barw(10) bc(gs9)) 
	(bar h2`type' x2`type', barw(5) bc(gs0) ) 
	, 
	xlabel(-100[100]200)
	ylabel(0(4)12, glc(gs12))
	xti("")  
	yti("Number of trades") 
	title("2014")
	legend(off)  
	graphregion(fcolor(gs16))
	;
#delimit cr	
graph save "`type'_t_diff_overall14", replace
drop x1`type'-h2`type'
}

foreach type in vol {
twoway__histogram_gen `type'_t_diff_chart if gameslot==1 & wc==0 	& trade==1 & cty~="BR" & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", percent width(10) gen(h1`type' x1`type')
twoway__histogram_gen `type'_t_diff_chart if owngame==1 			& trade==1 & cty~="BR" & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", percent width(10) gen(h2`type' x2`type')
#delimit ;
	twoway 
	(bar h1`type' x1`type', barw(10) bc(gs9)) 
	(bar h2`type' x2`type', barw(5) bc(gs0) ) 
	, 
	xlabel(-100[100]200)
	ylabel(0(8)24, glc(gs12))
	xti("")  
	yti("Traded volumes") 
	title("2014")
	legend(off)  
	graphregion(fcolor(gs16))
	;
#delimit cr	
graph save "$workdir/AnalysisJMCB/`type'_t_diff_overall14", replace
drop x1`type'-h2`type'
}
		
///////////////////////////////////////////////////////////////////////////////
	
	/// 1a. ATA FOR TICKS FOR 2014
eststo atat14ols1:		reg 		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE"
eststo atat14ols2:		reg 		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", vce(cl cty)
eststo atat14ols3:		reg 		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", vce(cl gamecounter)
eststo atat14pcse1:		xtpcse 		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", 
eststo atat14qreg:		qreg		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", 
eststo atat14qregr:		qreg		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", vce(r)
eststo atat14bsqreg:	bsqreg		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", 	
eststo atat14qreg4:		qreg2		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", cluster(cty) notest 
eststo atat14qreg5:		qreg2		tick_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", cluster(gamecounter) notest 

#delimit ;
esttab atat14ols1 atat14ols2 atat14ols3 atat14pcse1 atat14qreg atat14qregr atat14bsqreg atat14qreg4 atat14qreg5 
	using "$workdir/AnalysisJMCB/TableR4.csv", 
	b(2) se(2) ar(2) 
	star(* 0.05 ** 0.01)
	keep(gametime_all_benchmark game_time _cons)
	nonotes nogaps
	label fragment
	br
	mtitles("OLS" "OLS+cl cty" "OLS+cl game" "PCSE" "Median" "Median+robust" "Median+boots" "Median+cl cty" "Median+cl game")
	replace 
	;
#delimit cr

	/// 1b. ATA FOR VOLUMES FOR 2014
eststo atav14ols1:		reg 		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE"
eststo atav14ols2:		reg 		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", vce(cl cty)
eststo atav14ols3:		reg 		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", vce(cl gamecounter)
eststo atav14pcse1:		xtpcse 		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", 
eststo atav14qreg:		qreg		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", 
eststo atav14qregr:		qreg		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", vce(r)
eststo atav14bsqreg:	bsqreg		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", 
eststo atav14qreg4:		qreg2		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", cluster(cty) notest 
eststo atav14qreg5:		qreg2		vol_t_diff $RHS14 			if trade==1 & cty~="MCO" & cty~="MAR" & cty~="MBR" & cty~="MCL" & cty~="MMX" & cty~="MUS" & cty~="CA" & cty~="NZ" & cty~="PE", cluster(gamecounter) notest 

#delimit ;
esttab atav14ols1 atav14ols2 atav14ols3 atav14pcse1 atav14qreg atav14qregr atav14bsqreg atav14qreg4 atav14qreg5 
	using "$workdir/AnalysisJMCB/TableR5.csv", 
	b(2) se(2) ar(2) 
	star(* 0.05 ** 0.01)
	keep(gametime_all_benchmark game_time _cons)
	nonotes nogaps
	label fragment
	br
	mtitles("OLS" "OLS+cl cty" "OLS+cl game" "PCSE" "Median" "Median+robust" "Median+boots" "Median+cl cty" "Median+cl game")
	replace 
	;
#delimit cr

	/// 1c. Non participants ticks/volumes
eststo atat14olsclgamenonp:		reg		tick_t_diff	$RHS14 if trade==1 & (cty == "CA" | cty=="NZ" | cty=="PE"), vce(cl gamecounter)
eststo atav14olsclgamenonp:		reg		vol_t_diff 	$RHS14 if trade==1 & (cty == "CA" | cty=="NZ" | cty=="PE"), vce(cl gamecounter)
eststo atat14qreg2clgamenonp:	qreg2	tick_t_diff	$RHS14 if trade==1 & (cty == "CA" | cty=="NZ" | cty=="PE"), cluster(gamecounter) notest
eststo atav14qreg2clgamenonp:	qreg2	vol_t_diff 	$RHS14 if trade==1 & (cty == "CA" | cty=="NZ" | cty=="PE"), cluster(gamecounter) notest

	/// 1d. MSCI indices ticks/volumes
eststo atat14olsclgamemsci:		reg		tick_t_diff	$RHS14 if trade==1 & (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS"), vce(cl gamecounter)
eststo atav14olsclgamemsci:		reg		vol_t_diff 	$RHS14 if trade==1 & (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS"), vce(cl gamecounter)
eststo atat14qreg2clgamemsci:	qreg2	tick_t_diff	$RHS14 if trade==1 & (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS"), cluster(gamecounter) notest
eststo atav14qreg2clgamemsci:	qreg2	vol_t_diff 	$RHS14 if trade==1 & (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS"), cluster(gamecounter) notest

	/// 1e. Match events during national team matches 
eststo atat14olsclgamematchevents:	reg		tick_t_diff	game_time $RHSmatchevents2 if trade==1 & (cty == "AR" | cty == "CL" | cty== "MX" | cty == "US"), vce(cl gamecounter2)
eststo atav14olsclgamematchevents:	reg		vol_t_diff 	game_time $RHSmatchevents2 if trade==1 & (cty == "AR" | cty == "CL" | cty== "MX" | cty == "US"), vce(cl gamecounter2)
eststo atat14olsclgamematchevents2:	reg		tick_t_diff	game_time $RHSmatchevents2 if trade==1 & (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS"), vce(cl gamecounter2)
eststo atav14olsclgamematchevents2:	reg		vol_t_diff 	game_time $RHSmatchevents2 if trade==1 & (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS"), vce(cl gamecounter2)


	/// 2. DECOUPLING RESULTS 2014 (separate for national and MSCI indices / returns and excess returns)  (Table 5, columns 2 and 3 + extra)
#delimit ;
	eststo decoupl14a: 
	xtpcse stockreturn 
	stockreturn_MSCI interact game_time 
	durationa1 durationa2
	interactdurationa1 interactdurationa2
	if 
	trade==1 
	& (cty == "AR" | cty == "CL" | cty== "MX" | cty == "US")
	,
	pairw
	;
#delimit cr
	
#delimit ;
	eststo decoupl14b: 
	xtpcse stockreturn 
	stockreturn_MSCI interact game_time 
	durationa1 durationa2
	interactdurationa1 interactdurationa2
	if 
	trade==1 
	& (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS")
	,
	pairw
	;
#delimit cr


#delimit ;
	eststo decoupl14c: 
	xtpcse excessreturn 
	excessreturn_MSCI excessinteract game_time 
	durationa1 durationa2
	excessinteractdurationa1 excessinteractdurationa2
	if 
	trade==1 
	& (cty == "AR" | cty == "CL" | cty== "MX" | cty == "US")
	,
	pairw
	;
#delimit cr
	
#delimit ;
	eststo decoupl14d: 
	xtpcse excessreturn 
	excessreturn_MSCI excessinteract game_time 
	durationa1 durationa2
	excessinteractdurationa1 excessinteractdurationa2
	if 
	trade==1 
	& (cty == "MAR" | cty == "MCL" | cty== "MMX" | cty == "MUS")
	,
	pairw
	;
#delimit cr

	/// 3. RESPONSE TO REFEREE REPORT C (in Appendix)
do 		"$workdir/AnalysisJMCB/ReportC2014.do"

///////////////////////////////////////////////////////////////////////////////////////////////////

	/// TABLES 

// Table ATA (Table 2, panel A and B1)
#delimit ;
esttab atat10ols3 atat10qreg5 atav10ols3 atav10qreg5 atat14ols3 atat14qreg5 atav14ols3 atav14qreg5 
	using "$workdir/AnalysisJMCB/Table3_Particip.csv", 
	b(1) se(1)  
	star(* 0.05 ** 0.01)
	keep(gametime_all_benchmark game_time _cons)
	nonotes nogaps
	label fragment
	br
	//mtitles("OLS" "Median" "OLS" "Median" "OLS" "Median" "OLS" "Median")
	replace 
	;
#delimit cr

// Table non-participants 2014 (Table 2, panel B2)
#delimit ;
esttab atat14olsclgamenonp atav14olsclgamenonp atat14qreg2clgamenonp atav14qreg2clgamenonp  
	using "$workdir/AnalysisJMCB/Table3_NonParticip.csv", 
	b(1) se(1)  
	star(* 0.05 ** 0.01)
	keep(gametime_all_benchmark _cons)
	nonotes nogaps
	label fragment
	br
	mtitles("Trades / OLS" "Volumes / OLS" "Trades/ Median" " Volumes/ Median")
	replace 
	;
#delimit cr


// Table MSCI 2014 (Table 3)
#delimit ;
esttab atat14olsclgamemsci atav14olsclgamemsci atat14qreg2clgamemsci atav14qreg2clgamemsci  
	using "$workdir/AnalysisJMCB/Table4_MSCI.csv", 
	b(1) se(1)  
	star(* 0.05 ** 0.01)
	keep(gametime_all_benchmark game_time _cons)
	nonotes nogaps
	label fragment
	br
	mtitles("Trades / OLS" "Volumes / OLS" "Trades/ Median" " Volumes/ Median")
	replace 
	;
#delimit cr

// Table Match Events (Table 4)
#delimit ;
esttab atat10olsclgamematchevents atav10olsclgamematchevents atat14olsclgamematchevents atav14olsclgamematchevents atat14olsclgamematchevents2 atav14olsclgamematchevents2
	using "$workdir/AnalysisJMCB/Table5_MatchEvents.csv", 
	b(1) se(1) ar2
	star(* 0.05 ** 0.01)
	keep($RHSmatchevents2 game_time _cons)
	order($RHSmatchevents2 game_time _cons)
	nonotes nogaps
	label fragment
	br
	mtitles("2010: trades" "2010: volumes" "2014: trades" "2014: volumes" "2014: trades MSCI" "2014: volumes MSCI")
	replace 
	;
#delimit cr

// Table 5: Decoupling
#delimit ;
esttab decoupl10 decoupl14a decoupl14b
	using "$workdir/AnalysisJMCB/Table6.csv", 
	b(2) se(2) r2(2) 
	star(* 0.05 ** 0.01)
	keep(stockreturn_MSCI interact game_time 
	durationa1 durationa2
	interactdurationa1 interactdurationa2)
	order(stockreturn_MSCI interact game_time 
	durationa1 durationa2
	interactdurationa1 interactdurationa2)
	nonotes nogaps
	label fragment
	br
	mtitles("2010" "2014 national" "2014 MSCI")
	replace 
	;
#delimit cr

// Decoupling 2014 sample with excess returns
#delimit ;
esttab decoupl14c decoupl14d
	using "$workdir/AnalysisJMCB/Table6_excess.csv", 
	b(2) se(2) r2(2) 
	star(* 0.05 ** 0.01)
	keep(excessreturn_MSCI excessinteract game_time 
	durationa1 durationa2
	excessinteractdurationa1 excessinteractdurationa2)
	order(excessreturn_MSCI excessinteract game_time 
	durationa1 durationa2
	excessinteractdurationa1 excessinteractdurationa2)
	nonotes nogaps
	label fragment
	br
	mtitles("2014 national" "2014 MSCI")
	replace 
	;
#delimit cr

	/// FIGURE 1: ABNORMAL TRADING ACTIVITY (TRADES & TRADED VOLUMES) 
#delimit ;	
	graph combine 	
	"$workdir/AnalysisJMCB/tick_t_diff_overall10.gph" 
	"$workdir/AnalysisJMCB/tick_t_diff_overall14.gph"
	"$workdir/AnalysisJMCB/vol_t_diff_overall10.gph" 
	"$workdir/AnalysisJMCB/vol_t_diff_overall14.gph"
	, 
	graphregion(fcolor(gs16))
	col(2)
	;
#delimit cr
graph save 		"$workdir/AnalysisJMCB/Figure1", replace
graph export 	"$workdir/AnalysisJMCB/Figure1.png", replace	
graph export 	"$workdir/AnalysisJMCB/Figure1.eps", replace
graph export 	"$workdir/AnalysisJMCB/Figure1.pdf", replace	
graph export 	"$workdir/AnalysisJMCB/Figure1.tif", replace	

capture log cl

